@@ -18,8 +18,8 @@ from otcextensions import sdk
 LOG = logging.getLogger(__name__)
 
 DEFAULT_API_VERSION = '3'
-API_VERSION_OPTION = 'os_identity_api_version'
-API_NAME = "identity"
+API_VERSION_OPTION = 'os_iam_api_version'
+API_NAME = "iam"
 API_VERSIONS = {
     "3": "openstack.connection.Connection",
 }
@@ -30,7 +30,7 @@ def make_client(instance):
 
     conn = instance.sdk_connection
 
-    # register unconditionally, since we need to override default DNS
+    # register unconditionally, since we need to override default services
     sdk.register_otc_extensions(conn)
 
     LOG.debug('identity client initialized using OpenStack OTC SDK: %s',
